// Copyright © 2020 Amazon Web Services
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.util;


public class AwsConfig {



    public static String getAWSCognitoClientId() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_CLIENT_ID", "");
    }

    public static String getAWSCognitoAuthFlow() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_AUTH_FLOW", "USER_PASSWORD_AUTH");
    }

    public static String getAWSCognitoUser() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_AUTH_PARAMS_USER", "");
    }

    public static String getAWSCognitoPassword() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_AUTH_PARAMS_PASSWORD", "");
    }

    public static String getAWSCognitoNoAccessUser() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_AUTH_PARAMS_USER_NO_ACCESS", "");
    }


    public static String getAWSCognitoUserPoolID() {
        return getEnvironmentVariableOrDefaultValue("AWS_COGNITO_USER_POOL_ID", "");
    }

    public static String getResourcePrefix() {
        return getEnvironmentVariableOrDefaultValue("RESOURCE_PREFIX", "");
    }

    public static String getAwsRegion() {
        return getEnvironmentVariableOrDefaultValue("AWS_REGION", "us-east-1");
    }



    private static String getEnvironmentVariableOrDefaultValue(String key, String defaultValue) {
        String environmentVariable = getEnvironmentVariable(key);
        if (environmentVariable == null) {
            environmentVariable = defaultValue;
        }
        return environmentVariable;
    }

    private static String getEnvironmentVariable(String propertyKey) {
        return System.getProperty(propertyKey, System.getenv(propertyKey));
    }



}
