/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.notification.api;

import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.notification.util.BaseTestTemplate;
import org.opengroup.osdu.notification.util.Config;
import org.opengroup.osdu.notification.util.TestUtils;
import org.opengroup.osdu.core.common.notification.*;
import org.opengroup.osdu.core.common.model.notification.*;

import java.util.Base64;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public abstract class PubsubEndpointGSATests extends BaseTestTemplate {
    private static ISubscriptionService subscriptionService;
    private String subscriptionId;

    public static void classSetup(String token) throws Exception {
        descriptor = new PubsubEndpointGSADescriptor();
        //Configure Register Service Client Library
        SubscriptionAPIConfig config = SubscriptionAPIConfig.builder().rootUrl(Config.Instance().RegisterServicePath).build();
        SubscriptionFactory factory = new SubscriptionFactory(config);

        Map<String, String> headers = new HashMap<>();
        headers.put(DpsHeaders.DATA_PARTITION_ID, TestUtils.getOsduTenant());
        headers.put(DpsHeaders.AUTHORIZATION, token);
        DpsHeaders dpsHeaders = DpsHeaders.createFromMap(headers);
        subscriptionService = factory.create(dpsHeaders);
    }

    @Override
    protected String getArg() {
        return "";
    }

    @Override
    protected String getInvalidArg() {
        return "";
    }

    @Override
    protected void deleteResource() throws Exception {
        this.subscriptionService.delete(this.subscriptionId);
    }

    @Override
    protected void createResource() throws Exception {
        Subscription subscription = new Subscription();
        subscription.setTopic(Config.Instance().Topic);
        subscription.setPushEndpoint(Config.Instance().GSAPushUrl + "gsa-integration-test-" + UUID.randomUUID() + System.currentTimeMillis());
        subscription.setName("subscription-integration-test");
        subscription.setDescription("subscription created for integration test");
        Secret gsaSecret = new GsaSecret();
        GsaSecretValue gsaSecretValue = new GsaSecretValue();
        gsaSecretValue.setAudience(Config.Instance().IntegrationAudience);
        gsaSecretValue.setKey(new String(Base64.getDecoder().decode(Config.Instance().DE_OPS_TESTER)));
        gsaSecret.setSecretType("GSA");
        ((GsaSecret) gsaSecret).setValue(gsaSecretValue);
        subscription.setSecret(gsaSecret);
        try {
            subscription = this.subscriptionService.create(subscription);
        }catch (SubscriptionException e){
            System.out.println("Subscription exception inner response : " + e.getHttpResponse());
            throw e;
        }

        Config.Instance().NotificationId = subscription.getNotificationId();
        this.subscriptionId = subscription.getId();
    }

    @Override
    protected int expectedOkResponseCode() {
        return 200;
    }
}
